@@ -1,4 +1,4 @@
 from ploomber_engine.tracking.tracking import _cli
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     _cli()
